<template>
  <a-modal
    :title="title"
    :width="1200"
    :visible="visible"
    :maskClosable="false"
    @ok="handleOk"
    cancelText="关闭"
    @cancel="handleCancel"
    :confirmLoading="confirmLoading"
  >
    <a-spin :spinning="confirmLoading">
      <a-form :form="form">
        <a-row :gutter="24">
          <a-col :span="24/2">
            <a-form-item
              label="备件编码"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input-search
                :disabled="disableSubmit"
                placeholder="请选择备件！"
                enter-button
                @search="onSearchSparepartList()"
                :read-only="true"
                v-decorator="['sparePartNum', validatorRules.sparePartNum]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="24/2">
            <a-form-item
              label="出库单号"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                :disabled="true"
                enter-button
                :read-only="true"
                v-decorator="['num', validatorRules.num]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="24/2">
            <a-form-item
              label="备件名称"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                :disabled="true"
                enter-button
                :read-only="true"
                v-decorator="['sparePartName', validatorRules.sparePartName]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="24/2">
            <a-form-item
              label="备件规格"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                :disabled="true"
                enter-button
                :read-only="true"
                v-decorator="['sparePartSpecification', validatorRules.sparePartSpecification]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="24/2">
            <a-form-item
              label="备件型号"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                :disabled="true"
                enter-button
                :read-only="true"
                v-decorator="['sparePartModel', validatorRules.sparePartModel]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="24/2">
            <a-form-item
              label="制造商"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'请输入制造商'"
                v-decorator="['constructorName', validatorRules.constructorName ]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="24/2">
            <a-form-item
              label="主单位"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'请输入主单位'"
                v-decorator="['mainUnitName', validatorRules.mainUnitName ]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="24/2">
            <a-form-item label="数量" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-input v-decorator="['actualQuantity', validatorRules.actualQuantity]" placeholder="请输入数量" ></a-input>
            </a-form-item>
          </a-col>
          <a-col :span="12" hidden>
            <a-form-item
              label="备件Id"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                :disabled="true"
                :placeholder="disableSubmit?'':'请输入备件'"
                v-decorator="['sparePartId', validatorRules.sparePartId ]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="12" hidden>
            <a-form-item
              label="制造商Id"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                :disabled="true"
                :placeholder="disableSubmit?'':'请输入制造商'"
                v-decorator="['constructorId', validatorRules.constructorId ]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="12" hidden>
            <a-form-item
              label="单位Id"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                :disabled="true"
                :placeholder="disableSubmit?'':'请输入单位'"
                v-decorator="['mainUnitId', validatorRules.mainUnitId ]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="12" hidden>
            <a-form-item
              label="出库单Id"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                :disabled="true"
                :placeholder="disableSubmit?'':'请输入出库单'"
                v-decorator="['outboundOrderId', validatorRules.outboundOrderId ]"
              />
            </a-form-item>
          </a-col>
          </a-row>
      </a-form>
    </a-spin>

    <template slot="footer">
      <a-button
        :style="{marginRight: '8px'}"
        @click="handleCancel()"
      >
        关闭
      </a-button>

      <a-button
        @click="handleOk()"
        type="primary"
        :loading="confirmLoading"
      >确定</a-button>
    </template>

    <j-select-spare-part-modal
      ref='sparePartModalForm'
      @sendSparePartRecord='sendSparePartRecord'
      ></j-select-spare-part-modal>

  </a-modal>

</template>

<script>
import { getAction, postAction, requestPut } from '@/api/manage'
import pick from 'lodash.pick'
import JMultiSelectTag from '@/components/dict/JMultiSelectTag'
import { duplicateCheck } from '@/api/api'
import Tooltip from 'ant-design-vue/es/tooltip'
// import JImageUpload from '@/components/jeecg/JImage2Upload'
import JSelectSparePartModal from '../../repairOrderFinishedReport/modules/JSelectSparePartModal'
import Vue from 'vue'

export default {
  name: "RepairOrderActualMaterialReportModal",
  components: {
    JMultiSelectTag,
    Tooltip,
    JSelectSparePartModal
  },
  data() {
    return {
      title: "操作",
      visible: false,
      disableSubmit: false,
      codeDisable: true,
      model: {},
      departs: [],
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      confirmLoading: false,
      form: this.$form.createForm(this),
      validatorRules: {
        sparepartNum: {
          rules: [
            { required: true, message: '请选择备件!' },
          ]
        },
      },
      url: {
        add: '/eam/reportAfterRepair/addActualMaterial',
        edit: '/eam/repairOrderActualMaterial/edit'
      },

      dataSource: [],
    }
  },

  props: {
    reportAfterRepairId:{
        type:String,
        default:'',
        required:false
      },
  },

  created() {
  },

  mounted() {
    this.$bus.$on('selectionRows', (data) => {
      for (let i = 0; i < data.length; i++) {
        this.dataSource.push({
          id: data[i].id,
          num: data[i].num,
        })
      }

    })
  },

  methods: {

    add() {
      this.edit({})
    },
    edit(record) {
      let that = this;
      that.dataSource = [];
      that.form.resetFields();
      that.model = Object.assign({}, record);
      that.visible = true;
      that.$nextTick(() => {
        that.form.setFieldsValue(pick(that.model, 'num', 'sparePartId','sparePartNum', 'sparePartName','sparePartModel', 'sparePartSpecification','actualQuantity','mainUnitName','constructorName'));
      });
      if (record.id) {
        this.codeDisable = true;
      } else {
        this.codeDisable = false;
      }
    },

    onSearchSparepartList() {
      this.$refs.sparePartModalForm.list();
      this.$refs.sparePartModalForm.title = "选择备件信息";
    },
    sendSparePartRecord(data) {
      this.dataSource = [];
      let record = data.record;
      this.form.setFieldsValue({ num: record.num,
          outboundOrderId:record.outboundOrderId,
          sparePartId:record.sparePartId,
          sparePartNum: record.spareNum,
          sparePartName: record.spareName,
          sparePartSpecification: record.specification,
          sparePartModel:record.model,
          constructorName:record.constructorName,
          constructorId:record.constructorId,
          mainUnitName:record.mainUnitName,
          mainUnitId:record.mainUnitId, });
    },

    close() {
      this.$emit('close');
      this.visible = false;
    },

    handleCancel() {
      this.close();
    },

    handleOk() {
      const that = this;
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true;
          let formData = Object.assign(this.model, values);
          formData.reportAfterRepairId = this.reportAfterRepairId;
          let obj;
          if (!this.model.id) {
            obj = postAction(this.url.add, formData);
          } else {
            obj = requestPut(this.url.edit, formData, { id: this.model.id });
          }
          obj.then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        }
      })
    },


  },
}
</script>

<style lang="less" scoped>
/deep/ .frozenRowClass {
  color: #c9c9c9;
}
.fontweight {
  font-weight: bold;
}
.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}
</style>